@@ -5,6 +5,7 @@
 
 use strict;
 use Archive::Zip qw(:ERROR_CODES :CONSTANTS);
+use Archive::Zip::Tree;
 
 die "usage: $0 zipfile.zip file [...]\n"
 	if (scalar(@ARGV) < 2);
@@ -12,7 +13,7 @@ die "usage: $0 zipfile.zip file [...]\n"
 my $zipName = shift(@ARGV);
 my $zip = Archive::Zip->new();
 
-foreach my $memberName (map { glob } @ARGV)
+foreach my $memberName (@ARGV)
 {
 	if (-d $memberName )
 	{
